#
# Copyright (c) 2021-2025 ahriman team.
#
# This file is part of ahriman
# (see https://github.com/arcan1s/ahriman).
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
#
import uuid

from dataclasses import dataclass
from typing import Any, ClassVar


@dataclass(frozen=True)
class LogRecordId:
    """
    log record process identifier

    Attributes:
        package_base(str): package base for which log record belongs
        version(str): package version for which log record belongs
        _process_id(str | None, optional): unique process identifier
    """

    package_base: str
    version: str
    _process_id: str | None = None

    DEFAULT_PROCESS_ID: ClassVar[str] = str(uuid.uuid4())

    @property
    def process_id(self) -> str:
        """
        unique process identifier

        Returns:
            str: process identifier as set
        """
        return self._process_id or self.DEFAULT_PROCESS_ID

    def __eq__(self, other: Any) -> bool:
        """
        check if other is the same object

        Args:
            other(Any): other object instance

        Returns:
            bool: ``True`` if the other object is the same and ``False`` otherwise
        """
        if not isinstance(other, LogRecordId):
            return False
        return self.package_base == other.package_base \
            and self.version == other.version \
            and self.process_id == other.process_id
